summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorushen <yshxxsjt715@gmail.com>2020-04-05 20:54:03 +0800
committerushen <yshxxsjt715@gmail.com>2020-04-05 20:55:04 +0800
commit2c2779a974d59a9d91bd7cb1e3ae001952fe9083 (patch)
tree9379b2ea7d0e2868dcbd8247d1c525098acaa4dc
parent7f638bb493571f2a6d30d3679945119d6596cfa7 (diff)
downloadoslo-messaging-2c2779a974d59a9d91bd7cb1e3ae001952fe9083.tar.gz
Fix some typos
Change-Id: Ic0a311d290682a923ec4f8cbe36f875d560cd41a
-rw-r--r--oslo_messaging/_drivers/amqpdriver.py6
-rw-r--r--oslo_messaging/_drivers/impl_rabbit.py4
2 files changed, 5 insertions, 5 deletions
diff --git a/oslo_messaging/_drivers/amqpdriver.py b/oslo_messaging/_drivers/amqpdriver.py
index a41ff24..89e3fd3 100644
--- a/oslo_messaging/_drivers/amqpdriver.py
+++ b/oslo_messaging/_drivers/amqpdriver.py
@@ -151,7 +151,7 @@ class AMQPIncomingMessage(base.RpcIncomingMessage):
except rpc_amqp.AMQPDestinationNotFound:
if timer.check_return() > 0:
LOG.debug(("The reply %(msg_id)s cannot be sent "
- "%(reply_q)s reply queue don't exist, "
+ "%(reply_q)s reply queue doesn't exist, "
"retrying..."), {
'msg_id': self.msg_id,
'reply_q': self.reply_q})
@@ -220,7 +220,7 @@ class NotificationAMQPIncomingMessage(AMQPIncomingMessage):
class ObsoleteReplyQueuesCache(object):
- """Cache of reply queue id that doesn't exists anymore.
+ """Cache of reply queue id that doesn't exist anymore.
NOTE(sileht): In case of a broker restart/failover
a reply queue can be unreachable for short period
@@ -259,7 +259,7 @@ class ObsoleteReplyQueuesCache(object):
self._no_reply_log(reply_q, msg_id)
def _no_reply_log(self, reply_q, msg_id):
- LOG.warning("%(reply_queue)s doesn't exists, drop reply to "
+ LOG.warning("%(reply_queue)s doesn't exist, drop reply to "
"%(msg_id)s", {'reply_queue': reply_q, "msg_id": msg_id})
diff --git a/oslo_messaging/_drivers/impl_rabbit.py b/oslo_messaging/_drivers/impl_rabbit.py
index 46c5ae0..2018c5e 100644
--- a/oslo_messaging/_drivers/impl_rabbit.py
+++ b/oslo_messaging/_drivers/impl_rabbit.py
@@ -59,7 +59,7 @@ else:
# we will facing an issue by trying to override the threading module.
stdlib_threading = threading
# NOTE(sileht): don't exists in py2 socket module
TCP_USER_TIMEOUT = 18
rabbit_opts = [
@@ -1286,7 +1286,7 @@ class Connection(object):
# the 404 kombu ChannelError and retry until the exchange
# appears
raise rpc_amqp.AMQPDestinationNotFound(
- "exchange %s doesn't exists" % exchange.name)
+ "exchange %s doesn't exist" % exchange.name)
raise
def direct_send(self, msg_id, msg):
@@ -59,7 +59,7 @@ else:
# we will facing an issue by trying to override the threading module.
stdlib_threading = threading
-# NOTE(sileht): don't exists in py2 socket module
+# NOTE(sileht): don't exist in py2 socket module
TCP_USER_TIMEOUT = 18
rabbit_opts = [